EXPORTS
	??0CObexClientMtm@@IAE@AAVCRegisteredMtmDll@@AAVCMsvSession@@VTUid@@@Z @ 1 NONAME ; protected: __thiscall CObexClientMtm::CObexClientMtm(class CRegisteredMtmDll &,class CMsvSession &,class TUid)
	??1CObexClientMtm@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CObexClientMtm::~CObexClientMtm(void)
	?AddAddresseeL@CObexClientMtm@@UAEXABVTDesC16@@0@Z @ 3 NONAME ; public: virtual void __thiscall CObexClientMtm::AddAddresseeL(class TDesC16 const &,class TDesC16 const &)
	?AddAddresseeL@CObexClientMtm@@UAEXABVTDesC16@@@Z @ 4 NONAME ; public: virtual void __thiscall CObexClientMtm::AddAddresseeL(class TDesC16 const &)
	?CommitChangesL@CObexClientMtm@@QAEXXZ @ 5 NONAME ; public: void __thiscall CObexClientMtm::CommitChangesL(void)
	?ConstructL@CObexClientMtm@@IAEXXZ @ 6 NONAME ; protected: void __thiscall CObexClientMtm::ConstructL(void)
	?ContextEntrySwitched@CObexClientMtm@@MAEXXZ @ 7 NONAME ; protected: virtual void __thiscall CObexClientMtm::ContextEntrySwitched(void)
	?CreateMessageL@CObexClientMtm@@UAEXJ@Z @ 8 NONAME ; public: virtual void __thiscall CObexClientMtm::CreateMessageL(long)
	?Find@CObexClientMtm@@UAEIABVTDesC16@@I@Z @ 9 NONAME ; public: virtual unsigned int __thiscall CObexClientMtm::Find(class TDesC16 const &,unsigned int)
	?ForwardL@CObexClientMtm@@UAEPAVCMsvOperation@@JIAAVTRequestStatus@@@Z @ 10 NONAME ; public: virtual class CMsvOperation * __thiscall CObexClientMtm::ForwardL(long,unsigned int,class TRequestStatus &)
	?GetAttachmentSizeL@CObexClientMtm@@QAEJXZ @ 11 NONAME ; public: long __thiscall CObexClientMtm::GetAttachmentSizeL(void)
	?GetPasswordLC@CObexClientMtm@@QAEPAVHBufC16@@XZ @ 12 NONAME ABSENT ; public: class HBufC16 * __thiscall CObexClientMtm::GetPasswordLC(void)
	?InvokeSyncFunctionL@CObexClientMtm@@UAEXHABVCMsvEntrySelection@@AAVTDes8@@@Z @ 13 NONAME ; public: virtual void __thiscall CObexClientMtm::InvokeSyncFunctionL(int,class CMsvEntrySelection const &,class TDes8 &)
	?LoadMessageL@CObexClientMtm@@UAEXXZ @ 14 NONAME ; public: virtual void __thiscall CObexClientMtm::LoadMessageL(void)
	?QueryCapability@CObexClientMtm@@UAEHVTUid@@AAH@Z @ 15 NONAME ; public: virtual int __thiscall CObexClientMtm::QueryCapability(class TUid,int &)
	?RemoveAddressee@CObexClientMtm@@UAEXH@Z @ 16 NONAME ; public: virtual void __thiscall CObexClientMtm::RemoveAddressee(int)
	?ReplyL@CObexClientMtm@@UAEPAVCMsvOperation@@JIAAVTRequestStatus@@@Z @ 17 NONAME ; public: virtual class CMsvOperation * __thiscall CObexClientMtm::ReplyL(long,unsigned int,class TRequestStatus &)
	?SaveMessageL@CObexClientMtm@@UAEXXZ @ 18 NONAME ; public: virtual void __thiscall CObexClientMtm::SaveMessageL(void)
	?SetPasswordL@CObexClientMtm@@QAEXABVTDesC16@@@Z @ 19 NONAME ABSENT ; public: void __thiscall CObexClientMtm::SetPasswordL(class TDesC16 const &)
	?SetSubjectL@CObexClientMtm@@UAEXABVTDesC16@@@Z @ 20 NONAME ; public: virtual void __thiscall CObexClientMtm::SetSubjectL(class TDesC16 const &)
	?SubjectL@CObexClientMtm@@UBE?BVTPtrC16@@XZ @ 21 NONAME ; public: virtual class TPtrC16 const  __thiscall CObexClientMtm::SubjectL(void)const 
	?ValidateMessage@CObexClientMtm@@UAEII@Z @ 22 NONAME ; public: virtual unsigned int __thiscall CObexClientMtm::ValidateMessage(unsigned int)
	?CommitFileNameExternaliseL@CObexClientMtm@@QAEXXZ @ 23 NONAME ABSENT ; public: void __thiscall CObexClientMtm::CommitFileNameExternaliseL(void)
	?ExternaliseFileNameAndHeadersL@CObexClientMtm@@QAEXABVTDesC16@@ABVCObexHeaderList@@@Z @ 24 NONAME ABSENT ; public: void __thiscall CObexClientMtm::ExternaliseFileNameAndHeadersL(class TDesC16 const &,class CObexHeaderList const &)
	?ExternaliseFileNameL@CObexClientMtm@@QAEXABVTDesC16@@@Z @ 25 NONAME ABSENT ; public: void __thiscall CObexClientMtm::ExternaliseFileNameL(class TDesC16 const &)
	?StartFileNameExternaliseL@CObexClientMtm@@QAEXABVCMsvEntrySelection@@@Z @ 26 NONAME ABSENT ; public: void __thiscall CObexClientMtm::StartFileNameExternaliseL(class CMsvEntrySelection const &)
	?CreateMessageAttachmentL@CObexClientMtm@@QAEXJ@Z @ 27 NONAME ; void CObexClientMtm::CreateMessageAttachmentL(long)

